@@ -9,11 +9,11 @@ App::HWD - The great new App::HWD!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.04
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -61,6 +61,10 @@ your bug as I make changes.
 
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to
+Neil Watkiss
+and Luke Closs for features and patches.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2005 Andy Lester, all rights reserved.
